#' LRT function 
#'
#' This function performs a a likelihood ratio test to calculate a p-value from the log likelihoods of two nested models.
#'
#' @param l1 numeric. Log likelihood of alternative model fit.
#' @param l0 numeric. Log likelihood of null model fit.
#' @param dF integer. degrees of freedom for test, i.e.number of parameters in alternative model - number of parameters in null model. 
#' @return p-value from athe likelihood ratio test
#' @details
#' Calculates a likelihood ratio test from the log likelihoods of nested models. 
#' Note, if the number of variance parameters changes, then the models should be fit with REML, 
#' If the number of fixed parameters changes, the model should be fit with ML
#' The test is not valid for unnested models or nessted models varying in both fixed and random effects. 
#' @keywords Likelihood ratio test
#' @export
LRT <- function(L1, L0, dF){
	T <- 2 * (L1 - L0)
	pchisq(T, dF, lower.tail = FALSE)
}
