% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/genCov.R
\name{genCov}
\alias{genCov}
\title{genCov function}
\usage{
genCov(M, lambda = 0.01, returnH = FALSE)
}
\arguments{
\item{M}{matrix. A g x m matrix of m markers for g genotypes. Cannot handle missing data as is. Impute with marker score mean for a quick fix!}

\item{lambda}{numeric. Matrix bending coefficient to be added to the diagonal of the covariance matrix to recover full rank after centering. Centering projects X onto n-1 dimensional subspace (i.e. X is rank deficient)}

\item{returnH}{logical. if TRUE the additive by additive epistatic covariance is also returned along with the additive genetic covariance in a list of length 2.}
}
\value{
Additive and epistatic genetic covariances
}
\description{
This function calculates an additive genetic covariance matrix from dominant genetic marker coded {0, 1}, such as DArT markers.
}
\details{
Calculates the additive genetic covariance, K, based on dominant molecular markers based on method I of Van Raden (2008). 
If 'returnH' is set to TRUE, the additive by additive epistatic covariance, H, is also returned in a list with elements 'K' and 'H'. This is calculated according to Martini et al. (2016), but generally follows the methodology of Jiang et al. (2015)
}
\examples{
library(wheat)
data(wheat)

K <- genCov(wheat.X)
KH <- genCov(wheat.X, returnH = TRUE)
lapply(KH, dim)

}
\keyword{(and}
\keyword{,}
\keyword{:P)}
\keyword{Bayer}
\keyword{Crop}
\keyword{Genomic}
\keyword{K-fold}
\keyword{Monsanto}
\keyword{Science}
\keyword{Selection,}
\keyword{cross-validation}
