% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lreFit.R
\name{lreFit}
\alias{lreFit}
\title{lreFit function}
\usage{
lreFit(y, M, X, Z, index1, index2, verbose = FALSE,
  returnFullFit = FALSE)
}
\arguments{
\item{y}{numeric. Phenotype response vector of length n}

\item{M}{matrix. A g x m matrix of m markers for g genotypes. Cannot handle missing data as is. Impute with marker score mean for a quick fix!}

\item{X}{matrix. n x p design matrix. Cn include dummy variables (e.g. trials) as well as numeric covariates}

\item{Z}{matrix. n x g incidence matrix of genotypes}

\item{index1}{logical. Boolean vector of length m indicating which columns of M to include in region 1}

\item{index2}{logical. Boolean vector of length m indicating which columns of M to include in region 2}

\item{verbose}{logical. Boolean vector of length 1 indicating whether or not information from the model fit should be printed to stdout.}

\item{returnFullFit}{logical. Boolean vector of length 1 indicating whether or not the output from all EMMREML model fits should be returned.}
}
\value{
P-values for a model including the two regions as an additive effect and an interaction. Random effects (BLUPs) for the two regions specified as well as their interaction are also returned
}
\description{
This function fits three nested models for low resolution epistasis mapping using the EMMREML package to solve the mixed model equations.
}
\details{
This function fits the low resolution epistasis model proposed by Santantonio Jannink and Sorrells (2018). A low resolution epistasis mapping approach to identify chromosome arm interactions in allohexaploid wheat. Submitted to G3

Briefly, marker scores belonging to two regions indexed by arguments index1 and index2 are isolated from the remaining markers scores. These are used to cumpute additive genetic covarianes for each region and the remaining markers to fit additive kernels for each region while correcting for background additive and epistatic effecs. 

Three models are fit, the null model without the regions of interest, the additive model including the regions as additive kernels, and the interaction model that includes the interaction at the two regions. 

A nested likelihood ratio test is used to produce a p-value to determine if at least one additive variance componets is greater than zero, as well as if the interaction variance component is greater than zero. 

A list with elements 'pvalues' and 'BLUPs' containing pvalues and BLUPs for additive and interraction effects, respectively, is returned.
}
\examples{
data(CNLM)


}
\keyword{Low}
\keyword{epistasis}
\keyword{mapping.}
\keyword{resolution}
